<?php

namespace App\domain\travelport;

use Exception;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Facades\Storage;

class CreateWorkbench extends SearchOfferAPI
{
    protected int $traceId;

    public function __construct()
    {
        parent::__construct();
        $this->traceId = 3;
    }

    public function execute()
    {
        $apiUrl = $this->buildApiUrl();

        $payload = $this->createPayload();

        Storage::put('travelport/api/3-commit_initiate_workbench_request.json', json_encode($payload, JSON_PRETTY_PRINT));

        $headers = [
            ...$this->getHeaders(),
            'TraceID' => $this->traceId,
        ];

        $debugFile = fopen(storage_path('app/travelport/api/3-commit_initiate_workbench_request.txt'), 'a');

        try {
            $response = $this->client->post($apiUrl, [
                'headers' => $headers,
                'json' => $payload,
                'debug' => $debugFile
            ]);

            Storage::put('travelport/api/3-commit_initiate_workbench_response.json',json_encode(json_decode($response->getBody()), JSON_PRETTY_PRINT));

            return json_decode($response->getBody(), true);
        } catch (Exception $e) {
            echo 'Price Error: ' . $e->getMessage();
            return null;
        } catch (GuzzleException $e) {
            echo 'Error: ' . $e->getMessage();
            return null;
        }
    }

    protected function buildApiUrl(): string
    {
        return "https://{$this->baseURL}/{$this->apiVersion}/air/book/session/reservationworkbench";
    }

    protected function createPayload(): array
    {
        return [
            "ReservationID" => [
                "@type" => "ReservationID"
            ]
        ];
    }
}
