<?php

namespace App\domain\travelport;

use GuzzleHttp\Client;
use GuzzleHttp\HandlerStack;
use GuzzleHttp\MessageFormatter;
use GuzzleHttp\Middleware;
use Illuminate\Support\Facades\Log;

class TravelportAPI
{
    protected Client $client;
    protected string $baseURL;
    protected string $apiVersion;

    public function __construct()
    {
        $caCertPath = base_path('cacert.pem');

        // Create a new Guzzle client with middleware
        $stack = HandlerStack::create();
        $stack->push($this->createLoggingMiddleware());

        $this->client = new Client([
            'verify' => $caCertPath,
            'handler' => $stack
        ]);

        $this->baseURL = "api.pp.travelport.com";
        $this->apiVersion = "11";
    }

    protected function createLoggingMiddleware()
    {
        // Define the log format
        $logFormat = ">>>>>>>>\n{request}\n<<<<<<<<\n{response}";

        // Create a message formatter
        $formatter = new MessageFormatter($logFormat);

        // Create the middleware
        $middleware = Middleware::log(
            Log::channel('guzzle'), // Specify the log channel (you may need to configure this in your logging.php)
            $formatter
        );

        return $middleware;
    }

}
