<?php

namespace App\domain\travelport;

use App\domain\travelport\SearchOfferAPI;
use Exception;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Facades\Log;

abstract class Workbench extends SearchOfferAPI
{
    protected function travelportPost($traceId, $logFileName): mixed
    {
        $apiUrl = $this->buildApiUrl();
        $payload = $this->createPayload();

        $headers = [
            ...$this->getHeaders(),
            'TraceID' => $traceId,
        ];

        $debugFile = fopen(storage_path('app/travelport/api/' . $logFileName . '.txt'), 'a');

        try {
            $response = $this->client->post($apiUrl, [
                'headers' => $headers,
                'json' => $payload,
                'debug' => $debugFile
            ]);

            return json_decode($response->getBody(), true);
        } catch (Exception $e) {
            Log::error('Workbench Error: ' . $e->getMessage());
            return null;
        } catch (GuzzleException $e) {
            Log::error('Guzzle Error: ' . $e->getMessage());
            return null;
        }
    }


    abstract protected function buildApiUrl(): string;

    abstract protected function createPayload(): array;
}
