<?php

namespace App\domain\travelport\ticketing;

use App\domain\travelport\Workbench;
use Illuminate\Support\Facades\Storage;

class AddPaymentAction extends Workbench
{
    protected string $ticketWorkbenchAuthorityValue;
    protected string $payType;
    protected string $currencyCode;
    protected float $amount;
    protected string $formOfPaymentIdentifier;
    protected string $offerIdentifier;
    private string $offerId;

    protected int $traceId;

    public function __construct()
    {
        parent::__construct();
        $this->traceId = 9;
    }

    public function execute(
        string $ticketWorkbenchAuthorityValue,
        string $payType,
        string $currencyCode,
        float  $amount,
        string $formOfPaymentIdentifier,
        string $offerIdentifier,
        string $offerId,
    )
    {
        $this->ticketWorkbenchAuthorityValue = $ticketWorkbenchAuthorityValue;
        $this->payType = $payType;
        $this->currencyCode = $currencyCode;
        $this->amount = $amount;
        $this->formOfPaymentIdentifier = $formOfPaymentIdentifier;
        $this->offerIdentifier = $offerIdentifier;
        $this->offerId = $offerId;

        $response = $this->travelportPost($this->traceId, '9_add_payment_instruction_post_commit_reservation');

        Storage::put('travelport/api/9_add_payment_instruction_post_commit_reservation_response.json', json_encode($response, JSON_PRETTY_PRINT));

        return $response;
    }

    protected function buildApiUrl(): string
    {
        return "https://{$this->baseURL}/{$this->apiVersion}/air/paymentoffer/reservationworkbench/{$this->ticketWorkbenchAuthorityValue}/payments";
    }

    protected function createPayload(): array
    {
        $payload = [
            "Payment" => [
                "id" => "payment_1",
                "Identifier" => [
                    "authority" => "Travelport",
                    "value" => $this->formOfPaymentIdentifier
                ],
                "Amount" => [
                    "code" => $this->currencyCode,
                    "minorUnit" => 2,
                    "currencySource" => "Charged",
                    "approximateInd" => true,
                    "value" => $this->amount
                ],
                "FormOfPaymentIdentifier" => [
                    "id" => "formOfPayment_10",
                    "FormOfPaymentRef" => "formOfPayment_10",
                    "Identifier" => [
                        "authority" => "Travelport",
                        "value" => $this->formOfPaymentIdentifier
                    ]
                ],
                "OfferIdentifier" => [
                    [
                        "id" => $this->offerId,
                        "offerRef" => $this->offerId,
                        "Identifier" => [
                            "authority" => "Travelport",
                            "value" => $this->offerIdentifier
                        ]
                    ]
                ]
            ]
        ];
        Storage::put('travelport/api/9_add_payment_instruction_post_commit_reservation_request.json', json_encode($payload, JSON_PRETTY_PRINT));
        return $payload;
    }
}
