<?php

namespace App\domain\travelport\ticketing;

use App\domain\travelport\Workbench;
use Exception;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Storage;

class CommitReservationTicketIssuanceAction extends Workbench
{

    protected string $ticketWorkbenchAuthorityValue;
    protected int $traceId;

    public function __construct()
    {
        parent::__construct();
        $this->traceId = 10;
    }

    public function execute(string $ticketWorkbenchAuthorityValue)
    {
        $this->ticketWorkbenchAuthorityValue = $ticketWorkbenchAuthorityValue;

        $apiUrl = $this->buildApiUrl();

        $headers = [
            ...$this->getHeaders(),
            'TraceID' => $this->traceId,
        ];

        $debugFile = fopen(storage_path('app/travelport/api/10_commit_reservation_ticket_issuance.txt'), 'a');


        try {
            $response = $this->client->post($apiUrl, [
                'headers' => $headers,
                'debug' => $debugFile
            ]);

            Storage::put('travelport/api/10_commit_reservation_ticket_issuance_response.json',json_encode(json_decode($response->getBody()), JSON_PRETTY_PRINT));

            return json_decode($response->getBody(), true);
        } catch (Exception $e) {
            Log::error($e->getMessage());
            echo 'PostCommitInitiateWorkbenchAction Error: ' . $e->getMessage();

            return null;
        } catch (GuzzleException $e) {
            Log::error($e->getMessage());
            echo 'Error Post Commit Initiate workbench: ' . $e->getMessage();

            return null;
        }
    }

    protected function buildApiUrl(): string
    {
        return "https://{$this->baseURL}/{$this->apiVersion}/air/book/reservation/reservations/{$this->ticketWorkbenchAuthorityValue}";
    }

    protected function createPayload(): array
    {
        return [];
    }
}
