<?php

namespace App\domain\travelport\ticketing;

use App\domain\travelport\CreateOAuthTokens;
use App\domain\travelport\traits\TravelportTokenTrait;
use App\domain\travelport\Workbench;
use App\Models\CommitResponse;
use Exception;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Storage;

class PostCommitInitiateWorkbenchAction extends Workbench
{
    use TravelportTokenTrait;
    protected string $locatorId;

    protected int $traceId;

    public function __construct()
    {
        parent::__construct();
        $this->traceId = 7;
    }

    public function execute(string $locatorId): ?array
    {
        $this->locatorId = $locatorId;

        $apiUrl = $this->buildApiUrl();

        $headers = [
            ...$this->getHeaders(),
            'TraceID' => $this->traceId,
        ];

        $debugFile = fopen(storage_path('app/travelport/api/7-post_commit_initiate_workbench.txt'), 'a');

        try {
            $response = $this->client->post($apiUrl, [
                'headers' => $headers,
                'debug' => $debugFile
            ]);

            Storage::put('travelport/api/7-post_commit_initiate_workbench_response.json',json_encode(json_decode($response->getBody()), JSON_PRETTY_PRINT));

            return json_decode($response->getBody(), true);
        } catch (Exception $e) {
            Log::error($e->getMessage());
            echo 'PostCommitInitiateWorkbenchAction Error: ' . $e->getMessage();

            return null;
        } catch (GuzzleException $e) {
            Log::error($e->getMessage());
            echo 'Error Post Commit Initiate workbench: ' . $e->getMessage();

            return null;
        }
    }

    protected function getHeaders(): array
    {
        $this->getTravelportTokens();

        if (!session('access_token')) {
            $oAuthToken = new CreateOAuthTokens();
            $newOAuthToken = $oAuthToken->refreshOAuthAccessToken();

            if (!$newOAuthToken) {
                $tokens = $oAuthToken->requestOAuthAccessToken();
            }
        }

        return [
            'Accept' => 'application/json',
            'Accept-Encoding' => 'gzip, deflate, br',
            'XAUTH_TRAVELPORT_ACCESSGROUP' => '261EB763-521C-4649-B343-905B2F19A3D0',
            'Accept-Version' => $this->apiVersion,
            'Content-Version' => $this->apiVersion,
            'Authorization' => 'Bearer ' . session('access_token'),
        ];
    }

    protected function buildApiUrl(): string
    {
        return "https://{$this->baseURL}/{$this->apiVersion}/air/book/session/reservationworkbench/buildfromlocator?Locator={$this->locatorId}";
    }

    protected function createPayload(): array
    {
        return [];
    }
}
